@@ -1,21 +1,18 @@
-# encoding: utf-8
-
 """Unit test suite for docx.image.jpeg module"""
 
-from __future__ import absolute_import, print_function
+import io
 
 import pytest
 
-from docx.compat import BytesIO
 from docx.image.constants import JPEG_MARKER_CODE, MIME_TYPE
 from docx.image.helpers import BIG_ENDIAN, StreamReader
 from docx.image.jpeg import (
-    _App0Marker,
-    _App1Marker,
     Exif,
     Jfif,
-    _JfifMarkers,
     Jpeg,
+    _App0Marker,
+    _App1Marker,
+    _JfifMarkers,
     _Marker,
     _MarkerFactory,
     _MarkerFinder,
@@ -34,23 +31,19 @@ from ..unitutil.mock import (
 )
 
 
-class DescribeJpeg(object):
-
+class DescribeJpeg:
     def it_knows_its_content_type(self):
         jpeg = Jpeg(None, None, None, None)
         assert jpeg.content_type == MIME_TYPE.JPEG
 
     def it_knows_its_default_ext(self):
         jpeg = Jpeg(None, None, None, None)
-        assert jpeg.default_ext == 'jpg'
-
-    class DescribeExif(object):
+        assert jpeg.default_ext == "jpg"
 
+    class DescribeExif:
         def it_can_construct_from_an_exif_stream(self, from_exif_fixture):
             # fixture ----------------------
-            stream_, _JfifMarkers_, cx, cy, horz_dpi, vert_dpi = (
-                from_exif_fixture
-            )
+            stream_, _JfifMarkers_, cx, cy, horz_dpi, vert_dpi = from_exif_fixture
             # exercise ---------------------
             exif = Exif.from_stream(stream_)
             # verify -----------------------
@@ -61,12 +54,9 @@ class DescribeJpeg(object):
             assert exif.horz_dpi == horz_dpi
             assert exif.vert_dpi == vert_dpi
 
-    class DescribeJfif(object):
-
+    class DescribeJfif:
         def it_can_construct_from_a_jfif_stream(self, from_jfif_fixture):
-            stream_, _JfifMarkers_, cx, cy, horz_dpi, vert_dpi = (
-                from_jfif_fixture
-            )
+            stream_, _JfifMarkers_, cx, cy, horz_dpi, vert_dpi = from_jfif_fixture
             jfif = Jfif.from_stream(stream_)
             _JfifMarkers_.from_stream.assert_called_once_with(stream_)
             assert isinstance(jfif, Jfif)
@@ -85,9 +75,7 @@ class DescribeJpeg(object):
         jfif_markers_.sof.px_height = px_height
         jfif_markers_.app1.horz_dpi = horz_dpi
         jfif_markers_.app1.vert_dpi = vert_dpi
-        return (
-            stream_, _JfifMarkers_, px_width, px_height, horz_dpi, vert_dpi
-        )
+        return (stream_, _JfifMarkers_, px_width, px_height, horz_dpi, vert_dpi)
 
     @pytest.fixture
     def from_jfif_fixture(self, stream_, _JfifMarkers_, jfif_markers_):
@@ -97,13 +85,11 @@ class DescribeJpeg(object):
         jfif_markers_.sof.px_height = px_height
         jfif_markers_.app0.horz_dpi = horz_dpi
         jfif_markers_.app0.vert_dpi = vert_dpi
-        return (
-            stream_, _JfifMarkers_, px_width, px_height, horz_dpi, vert_dpi
-        )
+        return (stream_, _JfifMarkers_, px_width, px_height, horz_dpi, vert_dpi)
 
     @pytest.fixture
     def _JfifMarkers_(self, request, jfif_markers_):
-        _JfifMarkers_ = class_mock(request, 'docx.image.jpeg._JfifMarkers')
+        _JfifMarkers_ = class_mock(request, "docx.image.jpeg._JfifMarkers")
         _JfifMarkers_.from_stream.return_value = jfif_markers_
         return _JfifMarkers_
 
@@ -113,13 +99,12 @@ class DescribeJpeg(object):
 
     @pytest.fixture
     def stream_(self, request):
-        return instance_mock(request, BytesIO)
+        return instance_mock(request, io.BytesIO)
 
 
-class Describe_JfifMarkers(object):
-
+class Describe_JfifMarkers:
     def it_can_construct_from_a_jfif_stream(
-            self, stream_, _MarkerParser_, _JfifMarkers__init_, soi_, app0_, sof_, sos_
+        self, stream_, _MarkerParser_, _JfifMarkers__init_, soi_, app0_, sof_, sos_
     ):
         marker_lst = [soi_, app0_, sof_, sos_]
 
@@ -163,15 +148,11 @@ class Describe_JfifMarkers(object):
 
     @pytest.fixture
     def app0_(self, request):
-        return instance_mock(
-            request, _App0Marker, marker_code=JPEG_MARKER_CODE.APP0
-        )
+        return instance_mock(request, _App0Marker, marker_code=JPEG_MARKER_CODE.APP0)
 
     @pytest.fixture
     def app1_(self, request):
-        return instance_mock(
-            request, _App1Marker, marker_code=JPEG_MARKER_CODE.APP1
-        )
+        return instance_mock(request, _App1Marker, marker_code=JPEG_MARKER_CODE.APP1)
 
     @pytest.fixture
     def app0_fixture(self, soi_, app0_, eoi_):
@@ -187,9 +168,7 @@ class Describe_JfifMarkers(object):
 
     @pytest.fixture
     def eoi_(self, request):
-        return instance_mock(
-            request, _SofMarker, marker_code=JPEG_MARKER_CODE.EOI
-        )
+        return instance_mock(request, _SofMarker, marker_code=JPEG_MARKER_CODE.EOI)
 
     @pytest.fixture
     def _JfifMarkers__init_(self, request):
@@ -203,7 +182,7 @@ class Describe_JfifMarkers(object):
 
     @pytest.fixture
     def _MarkerParser_(self, request, marker_parser_):
-        _MarkerParser_ = class_mock(request, 'docx.image.jpeg._MarkerParser')
+        _MarkerParser_ = class_mock(request, "docx.image.jpeg._MarkerParser")
         _MarkerParser_.from_stream.return_value = marker_parser_
         return _MarkerParser_
 
@@ -228,9 +207,7 @@ class Describe_JfifMarkers(object):
 
     @pytest.fixture
     def sof_(self, request):
-        return instance_mock(
-            request, _SofMarker, marker_code=JPEG_MARKER_CODE.SOF0
-        )
+        return instance_mock(request, _SofMarker, marker_code=JPEG_MARKER_CODE.SOF0)
 
     @pytest.fixture
     def sof_fixture(self, soi_, sof_, eoi_):
@@ -240,23 +217,18 @@ class Describe_JfifMarkers(object):
 
     @pytest.fixture
     def soi_(self, request):
-        return instance_mock(
-            request, _Marker, marker_code=JPEG_MARKER_CODE.SOI
-        )
+        return instance_mock(request, _Marker, marker_code=JPEG_MARKER_CODE.SOI)
 
     @pytest.fixture
     def sos_(self, request):
-        return instance_mock(
-            request, _Marker, marker_code=JPEG_MARKER_CODE.SOS
-        )
+        return instance_mock(request, _Marker, marker_code=JPEG_MARKER_CODE.SOS)
 
     @pytest.fixture
     def stream_(self, request):
-        return instance_mock(request, BytesIO)
+        return instance_mock(request, io.BytesIO)
 
 
-class Describe_Marker(object):
-
+class Describe_Marker:
     def it_can_construct_from_a_stream_and_offset(self, from_stream_fixture):
         stream, marker_code, offset, _Marker__init_, length = from_stream_fixture
 
@@ -267,14 +239,16 @@ class Describe_Marker(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        (JPEG_MARKER_CODE.SOI,  2,  0),
-        (JPEG_MARKER_CODE.APP0, 4, 16),
-    ])
+    @pytest.fixture(
+        params=[
+            (JPEG_MARKER_CODE.SOI, 2, 0),
+            (JPEG_MARKER_CODE.APP0, 4, 16),
+        ]
+    )
     def from_stream_fixture(self, request, _Marker__init_):
         marker_code, offset, length = request.param
-        bytes_ = b'\xFF\xD8\xFF\xE0\x00\x10'
-        stream_reader = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
+        bytes_ = b"\xFF\xD8\xFF\xE0\x00\x10"
+        stream_reader = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
         return stream_reader, marker_code, offset, _Marker__init_, length
 
     @pytest.fixture
@@ -282,13 +256,12 @@ class Describe_Marker(object):
         return initializer_mock(request, _Marker)
 
 
-class Describe_App0Marker(object):
-
+class Describe_App0Marker:
     def it_can_construct_from_a_stream_and_offset(self, _App0Marker__init_):
-        bytes_ = b'\x00\x10JFIF\x00\x01\x01\x01\x00\x2A\x00\x18'
+        bytes_ = b"\x00\x10JFIF\x00\x01\x01\x01\x00\x2A\x00\x18"
         marker_code, offset, length = JPEG_MARKER_CODE.APP0, 0, 16
         density_units, x_density, y_density = 1, 42, 24
-        stream = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
+        stream = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
 
         app0_marker = _App0Marker.from_stream(stream, marker_code, offset)
 
@@ -299,9 +272,7 @@ class Describe_App0Marker(object):
 
     def it_knows_the_image_dpi(self, dpi_fixture):
         density_units, x_density, y_density, horz_dpi, vert_dpi = dpi_fixture
-        app0 = _App0Marker(
-            None, None, None, density_units, x_density, y_density
-        )
+        app0 = _App0Marker(None, None, None, density_units, x_density, y_density)
         assert app0.horz_dpi == horz_dpi
         assert app0.vert_dpi == vert_dpi
 
@@ -311,27 +282,26 @@ class Describe_App0Marker(object):
     def _App0Marker__init_(self, request):
         return initializer_mock(request, _App0Marker)
 
-    @pytest.fixture(params=[
-        (0, 100, 200,  72,  72),
-        (1, 100, 200, 100, 200),
-        (2, 100, 200, 254, 508),
-    ])
+    @pytest.fixture(
+        params=[
+            (0, 100, 200, 72, 72),
+            (1, 100, 200, 100, 200),
+            (2, 100, 200, 254, 508),
+        ]
+    )
     def dpi_fixture(self, request):
-        density_units, x_density, y_density, horz_dpi, vert_dpi = (
-            request.param
-        )
+        density_units, x_density, y_density, horz_dpi, vert_dpi = request.param
         return density_units, x_density, y_density, horz_dpi, vert_dpi
 
 
-class Describe_App1Marker(object):
-
+class Describe_App1Marker:
     def it_can_construct_from_a_stream_and_offset(
         self, _App1Marker__init_, _tiff_from_exif_segment_
     ):
-        bytes_ = b'\x00\x42Exif\x00\x00'
+        bytes_ = b"\x00\x42Exif\x00\x00"
         marker_code, offset, length = JPEG_MARKER_CODE.APP1, 0, 66
         horz_dpi, vert_dpi = 42, 24
-        stream = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
+        stream = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
 
         app1_marker = _App1Marker.from_stream(stream, marker_code, offset)
 
@@ -342,9 +312,9 @@ class Describe_App1Marker(object):
         assert isinstance(app1_marker, _App1Marker)
 
     def it_can_construct_from_non_Exif_APP1_segment(self, _App1Marker__init_):
-        bytes_ = b'\x00\x42Foobar'
+        bytes_ = b"\x00\x42Foobar"
         marker_code, offset, length = JPEG_MARKER_CODE.APP1, 0, 66
-        stream = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
+        stream = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
 
         app1_marker = _App1Marker.from_stream(stream, marker_code, offset)
 
@@ -353,8 +323,7 @@ class Describe_App1Marker(object):
         )
         assert isinstance(app1_marker, _App1Marker)
 
-    def it_gets_a_tiff_from_its_Exif_segment_to_help_construct(
-            self, get_tiff_fixture):
+    def it_gets_a_tiff_from_its_Exif_segment_to_help_construct(self, get_tiff_fixture):
         stream, offset, length = get_tiff_fixture[:3]
         BytesIO_, segment_bytes, substream_ = get_tiff_fixture[3:6]
         Tiff_, tiff_ = get_tiff_fixture[6:]
@@ -376,28 +345,31 @@ class Describe_App1Marker(object):
         return initializer_mock(request, _App1Marker)
 
     @pytest.fixture
-    def BytesIO_(self, request, substream_):
-        return class_mock(
-            request, 'docx.image.jpeg.BytesIO', return_value=substream_
+    def get_tiff_fixture(self, request, substream_, Tiff_, tiff_):
+        bytes_ = b"xfillerxMM\x00*\x00\x00\x00\x42"
+        stream_reader = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
+        BytesIO_ = class_mock(
+            request, "docx.image.jpeg.io.BytesIO", return_value=substream_
         )
-
-    @pytest.fixture
-    def get_tiff_fixture(self, request, BytesIO_, substream_, Tiff_, tiff_):
-        bytes_ = b'xfillerxMM\x00*\x00\x00\x00\x42'
-        stream_reader = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
         offset, segment_length, segment_bytes = 0, 16, bytes_[8:]
         return (
-            stream_reader, offset, segment_length, BytesIO_, segment_bytes,
-            substream_, Tiff_, tiff_
+            stream_reader,
+            offset,
+            segment_length,
+            BytesIO_,
+            segment_bytes,
+            substream_,
+            Tiff_,
+            tiff_,
         )
 
     @pytest.fixture
     def substream_(self, request):
-        return instance_mock(request, BytesIO)
+        return instance_mock(request, io.BytesIO)
 
     @pytest.fixture
     def Tiff_(self, request, tiff_):
-        Tiff_ = class_mock(request, 'docx.image.jpeg.Tiff')
+        Tiff_ = class_mock(request, "docx.image.jpeg.Tiff")
         Tiff_.from_stream.return_value = tiff_
         return Tiff_
 
@@ -408,18 +380,20 @@ class Describe_App1Marker(object):
     @pytest.fixture
     def _tiff_from_exif_segment_(self, request, tiff_):
         return method_mock(
-            request, _App1Marker, '_tiff_from_exif_segment', autospec=False,
-            return_value=tiff_
+            request,
+            _App1Marker,
+            "_tiff_from_exif_segment",
+            autospec=False,
+            return_value=tiff_,
         )
 
 
-class Describe_SofMarker(object):
-
+class Describe_SofMarker:
     def it_can_construct_from_a_stream_and_offset(self, request, _SofMarker__init_):
-        bytes_ = b'\x00\x11\x00\x00\x2A\x00\x18'
+        bytes_ = b"\x00\x11\x00\x00\x2A\x00\x18"
         marker_code, offset, length = JPEG_MARKER_CODE.SOF0, 0, 17
         px_width, px_height = 24, 42
-        stream = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
+        stream = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
 
         sof_marker = _SofMarker.from_stream(stream, marker_code, offset)
 
@@ -440,28 +414,34 @@ class Describe_SofMarker(object):
         return initializer_mock(request, _SofMarker)
 
 
-class Describe_MarkerFactory(object):
-
+class Describe_MarkerFactory:
     def it_constructs_the_appropriate_marker_object(self, call_fixture):
         marker_code, stream_, offset_, marker_cls_ = call_fixture
         marker = _MarkerFactory(marker_code, stream_, offset_)
-        marker_cls_.from_stream.assert_called_once_with(
-            stream_, marker_code, offset_
-        )
+        marker_cls_.from_stream.assert_called_once_with(stream_, marker_code, offset_)
         assert marker is marker_cls_.from_stream.return_value
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        JPEG_MARKER_CODE.APP0,
-        JPEG_MARKER_CODE.APP1,
-        JPEG_MARKER_CODE.SOF0,
-        JPEG_MARKER_CODE.SOF7,
-        JPEG_MARKER_CODE.SOS,
-    ])
+    @pytest.fixture(
+        params=[
+            JPEG_MARKER_CODE.APP0,
+            JPEG_MARKER_CODE.APP1,
+            JPEG_MARKER_CODE.SOF0,
+            JPEG_MARKER_CODE.SOF7,
+            JPEG_MARKER_CODE.SOS,
+        ]
+    )
     def call_fixture(
-            self, request, stream_, offset_, _App0Marker_, _App1Marker_,
-            _SofMarker_, _Marker_):
+        self,
+        request,
+        stream_,
+        offset_,
+        _App0Marker_,
+        _App1Marker_,
+        _SofMarker_,
+        _Marker_,
+    ):
         marker_code = request.param
         if marker_code == JPEG_MARKER_CODE.APP0:
             marker_cls_ = _App0Marker_
@@ -475,15 +455,15 @@ class Describe_MarkerFactory(object):
 
     @pytest.fixture
     def _App0Marker_(self, request):
-        return class_mock(request, 'docx.image.jpeg._App0Marker')
+        return class_mock(request, "docx.image.jpeg._App0Marker")
 
     @pytest.fixture
     def _App1Marker_(self, request):
-        return class_mock(request, 'docx.image.jpeg._App1Marker')
+        return class_mock(request, "docx.image.jpeg._App1Marker")
 
     @pytest.fixture
     def _Marker_(self, request):
-        return class_mock(request, 'docx.image.jpeg._Marker')
+        return class_mock(request, "docx.image.jpeg._Marker")
 
     @pytest.fixture
     def offset_(self, request):
@@ -491,15 +471,14 @@ class Describe_MarkerFactory(object):
 
     @pytest.fixture
     def _SofMarker_(self, request):
-        return class_mock(request, 'docx.image.jpeg._SofMarker')
+        return class_mock(request, "docx.image.jpeg._SofMarker")
 
     @pytest.fixture
     def stream_(self, request):
-        return instance_mock(request, BytesIO)
+        return instance_mock(request, io.BytesIO)
 
 
-class Describe_MarkerFinder(object):
-
+class Describe_MarkerFinder:
     def it_can_construct_from_a_stream(self, stream_, _MarkerFinder__init_):
         marker_finder = _MarkerFinder.from_stream(stream_)
 
@@ -517,30 +496,31 @@ class Describe_MarkerFinder(object):
     def _MarkerFinder__init_(self, request):
         return initializer_mock(request, _MarkerFinder)
 
-    @pytest.fixture(params=[
-        (0, JPEG_MARKER_CODE.SOI,   2),
-        (1, JPEG_MARKER_CODE.APP0,  4),
-        (2, JPEG_MARKER_CODE.APP0,  4),
-        (3, JPEG_MARKER_CODE.EOI,  12),
-        (4, JPEG_MARKER_CODE.EOI,  12),
-        (6, JPEG_MARKER_CODE.EOI,  12),
-        (8, JPEG_MARKER_CODE.EOI,  12),
-    ])
+    @pytest.fixture(
+        params=[
+            (0, JPEG_MARKER_CODE.SOI, 2),
+            (1, JPEG_MARKER_CODE.APP0, 4),
+            (2, JPEG_MARKER_CODE.APP0, 4),
+            (3, JPEG_MARKER_CODE.EOI, 12),
+            (4, JPEG_MARKER_CODE.EOI, 12),
+            (6, JPEG_MARKER_CODE.EOI, 12),
+            (8, JPEG_MARKER_CODE.EOI, 12),
+        ]
+    )
     def next_fixture(self, request):
         start, marker_code, segment_offset = request.param
-        bytes_ = b'\xFF\xD8\xFF\xE0\x00\x01\xFF\x00\xFF\xFF\xFF\xD9'
-        stream_reader = StreamReader(BytesIO(bytes_), BIG_ENDIAN)
+        bytes_ = b"\xFF\xD8\xFF\xE0\x00\x01\xFF\x00\xFF\xFF\xFF\xD9"
+        stream_reader = StreamReader(io.BytesIO(bytes_), BIG_ENDIAN)
         marker_finder = _MarkerFinder(stream_reader)
         expected_code_and_offset = (marker_code, segment_offset)
         return marker_finder, start, expected_code_and_offset
 
     @pytest.fixture
     def stream_(self, request):
-        return instance_mock(request, BytesIO)
+        return instance_mock(request, io.BytesIO)
 
 
-class Describe_MarkerParser(object):
-
+class Describe_MarkerParser:
     def it_can_construct_from_a_jfif_stream(
         self, stream_, StreamReader_, _MarkerParser__init_, stream_reader_
     ):
@@ -550,16 +530,20 @@ class Describe_MarkerParser(object):
         _MarkerParser__init_.assert_called_once_with(ANY, stream_reader_)
         assert isinstance(marker_parser, _MarkerParser)
 
-    def it_can_iterate_over_the_jfif_markers_in_its_stream(
-            self, iter_markers_fixture):
-        (marker_parser, stream_, _MarkerFinder_, marker_finder_,
-         _MarkerFactory_, marker_codes, offsets,
-         marker_lst) = iter_markers_fixture
-        markers = [marker for marker in marker_parser.iter_markers()]
+    def it_can_iterate_over_the_jfif_markers_in_its_stream(self, iter_markers_fixture):
+        (
+            marker_parser,
+            stream_,
+            _MarkerFinder_,
+            marker_finder_,
+            _MarkerFactory_,
+            marker_codes,
+            offsets,
+            marker_lst,
+        ) = iter_markers_fixture
+        markers = list(marker_parser.iter_markers())
         _MarkerFinder_.from_stream.assert_called_once_with(stream_)
-        assert marker_finder_.next.call_args_list == [
-            call(0), call(2), call(20)
-        ]
+        assert marker_finder_.next.call_args_list == [call(0), call(2), call(20)]
         assert _MarkerFactory_.call_args_list == [
             call(marker_codes[0], stream_, offsets[0]),
             call(marker_codes[1], stream_, offsets[1]),
@@ -579,34 +563,48 @@ class Describe_MarkerParser(object):
 
     @pytest.fixture
     def iter_markers_fixture(
-            self, stream_reader_, _MarkerFinder_, marker_finder_,
-            _MarkerFactory_, soi_, app0_, eoi_):
+        self,
+        stream_reader_,
+        _MarkerFinder_,
+        marker_finder_,
+        _MarkerFactory_,
+        soi_,
+        app0_,
+        eoi_,
+    ):
         marker_parser = _MarkerParser(stream_reader_)
         offsets = [2, 4, 22]
         marker_lst = [soi_, app0_, eoi_]
         marker_finder_.next.side_effect = [
-            (JPEG_MARKER_CODE.SOI,  offsets[0]),
+            (JPEG_MARKER_CODE.SOI, offsets[0]),
             (JPEG_MARKER_CODE.APP0, offsets[1]),
-            (JPEG_MARKER_CODE.EOI,  offsets[2]),
+            (JPEG_MARKER_CODE.EOI, offsets[2]),
         ]
         marker_codes = [
-            JPEG_MARKER_CODE.SOI, JPEG_MARKER_CODE.APP0, JPEG_MARKER_CODE.EOI
+            JPEG_MARKER_CODE.SOI,
+            JPEG_MARKER_CODE.APP0,
+            JPEG_MARKER_CODE.EOI,
         ]
         return (
-            marker_parser, stream_reader_, _MarkerFinder_, marker_finder_,
-            _MarkerFactory_, marker_codes, offsets, marker_lst
+            marker_parser,
+            stream_reader_,
+            _MarkerFinder_,
+            marker_finder_,
+            _MarkerFactory_,
+            marker_codes,
+            offsets,
+            marker_lst,
         )
 
     @pytest.fixture
     def _MarkerFactory_(self, request, soi_, app0_, eoi_):
         return class_mock(
-            request, 'docx.image.jpeg._MarkerFactory',
-            side_effect=[soi_, app0_, eoi_]
+            request, "docx.image.jpeg._MarkerFactory", side_effect=[soi_, app0_, eoi_]
         )
 
     @pytest.fixture
     def _MarkerFinder_(self, request, marker_finder_):
-        _MarkerFinder_ = class_mock(request, 'docx.image.jpeg._MarkerFinder')
+        _MarkerFinder_ = class_mock(request, "docx.image.jpeg._MarkerFinder")
         _MarkerFinder_.from_stream.return_value = marker_finder_
         return _MarkerFinder_
 
@@ -624,13 +622,12 @@ class Describe_MarkerParser(object):
 
     @pytest.fixture
     def stream_(self, request):
-        return instance_mock(request, BytesIO)
+        return instance_mock(request, io.BytesIO)
 
     @pytest.fixture
     def StreamReader_(self, request, stream_reader_):
         return class_mock(
-            request, 'docx.image.jpeg.StreamReader',
-            return_value=stream_reader_
+            request, "docx.image.jpeg.StreamReader", return_value=stream_reader_
         )
 
     @pytest.fixture
