@@ -1,18 +1,11 @@
-# encoding: utf-8
-
-"""
-Test suite for the docx.oxml.parts module.
-"""
-
-from __future__ import absolute_import, print_function, unicode_literals
+"""Test suite for the docx.oxml.parts module."""
 
 import pytest
 
 from ...unitutil.cxml import element, xml
 
 
-class DescribeCT_Body(object):
-
+class DescribeCT_Body:
     def it_can_clear_all_its_content(self, clear_fixture):
         body, expected_xml = clear_fixture
         body.clear_content()
@@ -26,13 +19,15 @@ class DescribeCT_Body(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        ('w:body',                 'w:body'),
-        ('w:body/w:p',             'w:body'),
-        ('w:body/w:tbl',           'w:body'),
-        ('w:body/w:sectPr',        'w:body/w:sectPr'),
-        ('w:body/(w:p, w:sectPr)', 'w:body/w:sectPr'),
-    ])
+    @pytest.fixture(
+        params=[
+            ("w:body", "w:body"),
+            ("w:body/w:p", "w:body"),
+            ("w:body/w:tbl", "w:body"),
+            ("w:body/w:sectPr", "w:body/w:sectPr"),
+            ("w:body/(w:p, w:sectPr)", "w:body/w:sectPr"),
+        ]
+    )
     def clear_fixture(self, request):
         before_cxml, after_cxml = request.param
         body = element(before_cxml)
@@ -41,11 +36,11 @@ class DescribeCT_Body(object):
 
     @pytest.fixture
     def section_break_fixture(self):
-        body = element('w:body/w:sectPr/w:type{w:val=foobar}')
+        body = element("w:body/w:sectPr/w:type{w:val=foobar}")
         expected_xml = xml(
-            'w:body/('
-            '  w:p/w:pPr/w:sectPr/w:type{w:val=foobar},'
-            '  w:sectPr/w:type{w:val=foobar}'
-            ')'
+            "w:body/("
+            "  w:p/w:pPr/w:sectPr/w:type{w:val=foobar},"
+            "  w:sectPr/w:type{w:val=foobar}"
+            ")"
         )
         return body, expected_xml
